<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Stream\Input;

// Import framework stuff
use Org\Mxchange\CoreFramework\Stream\Streamable;

/**
 * An interface for input streams
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2022 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface StreamableInput extends Streamable {
	/**
	 * Determines seek position
	 *
	 * @return	$seekPosition	Current seek position
	 */
	function determineSeekPosition ();

	/**
	 * Seek to given offset (default) or other possibilities as fseek() gives.
	 *
	 * @param	$offset		Offset to seek to (or used as "base" for other seeks)
	 * @param	$whence		Added to offset (default: only use offset to seek to)
	 * @return	void
	 * @throws	OutOfBoundsException	If the position is not seekable
	 */
	function seek (int $offset, int $whence = SEEK_SET);

	/**
	 * Size of file stack
	 *
	 * @return	$size	Size (in bytes) of file
	 */
	function size ();

}
