<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Resolver\Command;

// Import framework stuff
use Org\Mxchange\CoreFramework\Request\Requestable;
use Org\Mxchange\CoreFramework\Resolver\Resolver;

/**
 * An instance for command resolver classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2022 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface CommandResolver extends Resolver {
	/**
	 * Getter for command name
	 *
	 * @return	$commandName	Last validated command name
	 */
	function getCommandName ();

	/**
	 * Returns an command instance for a given request class or null if
	 * it was not found
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return	$commandInstance	An instance of the resolved command
	 * @throws	InvalidCommandException		Thrown if $commandName is invalid
	 * @throws	UnexpectedValueException	Thrown if $commandInstance is an invalid instance
	 */
	function resolveCommandByRequest (Requestable $requestInstance);

	/**
	 * Resolves the command by its direct name and returns an instance of its class
	 *
	 * @param	$namespace			Namespace to look in
	 * @param	$commandName		The direct command name we shall resolve
	 * @return	$commandInstance	An instance of the command class
	 * @throws	InvalidCommandException		Thrown if $commandName is invalid
	 */
	function resolveCommand (string $namespace, string $commandName);

}
